| mapsf-deprecated | R Documentation |
These functions and features still work but will be removed in the next major version of the package, which is scheduled in January 2027.
mf_map sub-functionsInstead of using the following deprecated functions, one can use mf_map with the corresponding type:
mf_base() => base
mf_choro() => choro
mf_prop() => prop
mf_typo() => typo
mf_symb() => symb
mf_grad() => grad
mf_prop_typo() => prop_typo
mf_prop_choro() => prop_choro
mf_symb_choro() => symb_choro
mf_initmf_init is deprecated. It is possible to use mf_map instead
(mf_map(x, type = "base", col = NA, border = NA).
It is also possible to use the extent argument of mf_map.
mf_exportmf_export is deprecated, use mf_png or mf_svg instead.
mf_annotationmf_annotation is deprecated, use mf_text instead.
The use of separated legends for map types prop_choro, prop_typo and
symb_choro is deprecated. Use leg_pos = NA and mf_legend if
separated legends are needed.
In mf_theme, the following themes are deprecated: "default", "brutal",
"ink", "dark", "agolalight", "candy", "darkula", "iceberg", "green",
"nevermind", "jsk" and "barcelona".
The following arguments are also deprecated: "bg", "fg", "tab",
"pos", "inner", "line", "cex" and "font".
Although the map theming system has been radically changed in version 1.0.0
of the package, you can still use the old themes by referencing them by name.
If you need to use the pre v1.0.0 default theme, set x to "default".
If an old theme is set, only deprecated arguments are used and others are
ignored.
If current and deprecated arguments are mixed, only deprecated arguments are
used and others are ignored.
All references and usages of the old theming system will be removed in the
next major version.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.