Learn R Programming

mapsf (version 1.2.0)

mf_init: Deprecated - Initialize a map with a specific extent

Description

This function is deprecated. Please use mf_map(x, col = NA, border = NA) instead.

Plot an invisible layer with the extent of a spatial object.
Always use add = TRUE in mf_map() calls following an mf_init() call. This function is similar to mf_map(x, col = NA, border = NA).

Usage

mf_init(x, expandBB = rep(0, 4), extent = x, bgc)

Value

No return value, a map is initiated.

Arguments

x

object of class sf, sfc or SpatRaster

expandBB

fractional values to expand the bounding box with, in each direction (bottom, left, top, right)

extent

object with an st_bbox method to define plot extent; defaults to x. extent and x must use the same CRS.

Examples

Run this code
mtq <- mf_get_mtq()
target <- mtq[30, ]
mf_map(target, type = "base", col = NA, border = NA)
mf_map(mtq, add = TRUE)
# or
mf_map(mtq, extent = target)

Run the code above in your browser using DataLab