Export a map with the extent of a spatial object in PNG format.
PNG is a raster graphics file format and PNG export should be used for
maps that do not require further modification.
If width is specified, then height is deduced from the width/height
ratio of x. Alternatively, if height is specified, then width
is deduced from the width/height ratio of x.
This helps to produce maps without too much wasted space.
Use dev.off to finish the export (see Examples).