Plot the shadow of a polygon layer.
Usage
mf_shadow(
x,
col,
cex = 1,
add = FALSE,
extent = x,
bg,
expandBB = rep(0.04, 4)
)Arguments
- x
an sf or sfc polygon object
- col
shadow color, hex code or color name given by colors. The default color is the highlight color (see mf_theme).
- cex
shadow extent
- add
whether to add the layer to an existing plot (TRUE) or not (FALSE)
- extent
sfobject used to define the map extent; defaults tox.extentandxmust use the same CRS.- bg
background color of the map, hex code or color name given by colors, ignored if
add = TRUE- expandBB
expension of the map area in each direction (bottom, left, top, right). The expension is expressed as a share of
xwidth (for left and right values) or a share ofxheight (for bottom and top values).
Examples
mtq <- mf_get_mtq()
mf_shadow(mtq)
mf_map(mtq, add = TRUE)