powered by
This function is deprecated. Please use mf_map() with type = "base" instead.
mf_map()
type = "base"
Plot an sf object. This is mostly a wrapper around plot(st_geometry(x), ...).
plot(st_geometry(x), ...)
mf_base( x, col, border, alpha = NULL, cex = 1, pch = 20, lwd = 0.7, lty = 1, add = FALSE, extent = x, bg, expandBB = rep(0.04, 4), ... )
x is (invisibly) returned.
object of class sf, sfc or sfg
sf
sfc
sfg
a color, hex code or color name given by colors
colors
border color
opacity, in the range 0,1
point size
pch (point type) for symbols
border width
line or border type
whether to add the layer to an existing plot (TRUE) or not (FALSE)
ignored
library(sf) mtq <- mf_get_mtq() mf_map(mtq, type = "base") mf_map(mtq, type = "base", col = "blue")
Run the code above in your browser using DataLab