This function is deprecated. Please use mf_map() with type = "grad"
instead.
Plot graduated symbols based on quantitative data.
mf_grad(
x,
var,
breaks = "quantile",
nbreaks = 3,
col,
alpha = NULL,
border,
pch = 21,
cex,
lwd,
extent = x,
bg,
expandBB = rep(0.04, 4),
leg_pos = mf_get_leg_pos(x),
leg_title = var,
leg_title_cex = 0.8,
leg_val_cex = 0.6,
leg_val_rnd = 0,
leg_val_dec = ".",
leg_val_big = "",
leg_frame = FALSE,
leg_adj = c(0, 0),
leg_size = 1,
leg_box_cex = c(1, 1),
leg_fg,
leg_bg,
leg_frame_border,
add = TRUE
)x is (invisibly) returned.
object of class sf
name(s) of the variable(s) to plot
either a numeric vector with the actual breaks, or a classification method name (see mf_get_breaks and Details)
number of classes
a color, hex code or color name given by colors
opacity, in the range 0,1
border color
pch (point type) for symbols
cex (point size) for symbols
border width
position of the legend, one of 'topleft', 'top','topright', 'right', 'bottomright', 'bottom', 'bottomleft', 'left' or a vector of two coordinates in map units (c(x, y)). Use NA to avoid plotting the legend, use 'interactive' to choose the legend position by clicking on the map.
legend title
size of the legend title
size of the values in the legend
number of decimal places of the values in the legend
decimal separator
thousands separator
whether to add a frame to the legend (TRUE) or not (FALSE)
adjust the position of the legend in x and y directions
size of the legend; 2 means two times bigger
width and height size expansion of boxes
color of the legend foreground
color of the legend background
border color of the legend frame
whether to add the layer to an existing plot (TRUE) or not (FALSE)
Breaks defined by a numeric vector or a classification method are
left-closed: breaks defined by c(2, 5, 10, 15, 20)
will be mapped as [2 - 5[, [5 - 10[, [10 - 15[, [15 - 20].
The "jenks" method is an exception and has to be right-closed.
Jenks breaks computed as c(2, 5, 10, 15, 20)
will be mapped as [2 - 5], ]5 - 10], ]10 - 15], ]15 - 20].
mtq <- mf_get_mtq()
mf_map(mtq)
mf_map(mtq, "POP", "grad", pch = 22)
Run the code above in your browser using DataLab