powered by
Plot the shadow of a polygon layer.
mf_shadow( x, col, cex = 1, add = FALSE, extent = x, bg, expandBB = rep(0.04, 4) )
x is (invisibly) returned.
an sf or sfc polygon object
shadow color. The default color is the highlight color (see mf_theme).
shadow extent
whether to add the layer to an existing plot (TRUE) or not (FALSE)
object with an st_bbox method to define plot extent; defaults to x. extent and x must use the same CRS.
st_bbox
x
extent
background color of the map, hex code or color name given by colors, ignored if add = TRUE
add = TRUE
fractional values to expand the bounding box with, in each direction (bottom, left, top, right)
mtq <- mf_get_mtq() mf_shadow(mtq) mf_map(mtq, add = TRUE)
Run the code above in your browser using DataLab